==> akonadi-import-wizard-16.12.0.tar.xz: akonadi-import-wizard-16.12.0/src/autodetect/selectcomponentpage.h <==
/*
   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef SELECTCOMPONENTPAGE_H
#define SELECTCOMPONENTPAGE_H

#include <QWidget>
#include "abstractimporter.h"

namespace Ui
{
class SelectComponentPage;
}

class SelectComponentPage : public QWidget
{
    Q_OBJECT

public:
    explicit SelectComponentPage(QWidget *parent = Q_NULLPTR);
    ~SelectComponentPage();

    void setEnabledComponent(AbstractImporter::TypeSupportedOptions options);
    AbstractImporter::TypeSupportedOptions selectedComponents() const;

Q_SIGNALS:
    void atLeastOneComponentSelected(bool componentSelected);

private:
    void slotEverythingClicked(bool clicked);
    void slotComponentClicked();
    AbstractImporter::TypeSupportedOptions mOptions;
    Ui::SelectComponentPage *ui;
};

#endif // SELECTCOMPONENTPAGE_H

==> akonadi-import-wizard-17.08.3.tar.xz: akonadi-import-wizard-17.08.3/src/autodetect/selectcomponentpage.h <==
/*
   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef SELECTCOMPONENTPAGE_H
#define SELECTCOMPONENTPAGE_H

#include <QWidget>
#include "abstractimporter.h"

namespace Ui {
class SelectComponentPage;
}

class SelectComponentPage : public QWidget
{
    Q_OBJECT

public:
    explicit SelectComponentPage(QWidget *parent = nullptr);
    ~SelectComponentPage();

    void setEnabledComponent(LibImportWizard::AbstractImporter::TypeSupportedOptions options);
    LibImportWizard::AbstractImporter::TypeSupportedOptions selectedComponents() const;

Q_SIGNALS:
    void atLeastOneComponentSelected(bool componentSelected);

private:
    void slotEverythingClicked(bool clicked);
    void slotComponentClicked();
    LibImportWizard::AbstractImporter::TypeSupportedOptions mOptions;
    Ui::SelectComponentPage *ui;
};

#endif // SELECTCOMPONENTPAGE_H
